@@ -1,3 +1,3 @@
 from .version import __version__
-from .model import EnodoModel
+from .model import EnodoModel, EnodoModelArgument
 from .model.config.worker import WorkerConfigModel
